using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace GameState
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        SpriteManager spriteManager;
        #region GameState Code
        KeyboardState cK;
        KeyboardState pK = Keyboard.GetState();

        enum GameState { Start, InGame, GameOver };
        GameState currentGameState = GameState.Start;

        Texture2D titlescreen;
        Texture2D endscreen;
        Texture2D gamescreen;

        int counter = 0;

        public int Counter
        {
            get { return counter; }

            set
            {
                counter = value;
                if (counter == 0)
                {
                    currentGameState = GameState.GameOver;
                    spriteManager.Enabled = false;
                    spriteManager.Visible = false;
                }
            }
        }
        #endregion

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

        }


        protected override void Initialize()
        {
            spriteManager = new SpriteManager(this);
            Components.Add(spriteManager);

            spriteManager.Enabled = false;
            spriteManager.Visible = false;

            base.Initialize();
        }

        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            titlescreen = Content.Load<Texture2D>(@"StateScreens/mainScreen");
            endscreen = Content.Load<Texture2D>(@"StateScreens/endScreen");
            gamescreen = Content.Load<Texture2D>(@"StateScreens/BackgroundPath");
        }

        protected override void UnloadContent()
        {

        }

        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();



            #region GameState Code
            cK = Keyboard.GetState();

            switch (currentGameState)
            {
                case GameState.Start:
                    if (cK.IsKeyDown(Keys.Space) && pK.IsKeyUp(Keys.Space))
                    {
                        currentGameState = GameState.InGame;
                        spriteManager.Enabled = true;
                        spriteManager.Visible = true;
                        counter = 0;
                    }
                    break;

                case GameState.InGame:
                    if (cK.IsKeyDown(Keys.Space) && pK.IsKeyUp(Keys.Space))
                    {
                        currentGameState = GameState.GameOver;
                    }
                    break;

                case GameState.GameOver:

                    if (cK.IsKeyDown(Keys.Space) && pK.IsKeyUp(Keys.Space))
                    {
                        currentGameState = GameState.Start;
                    }
                    break;
            }

            pK = cK;
            #endregion

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            #region GameState Code
            switch (currentGameState)
            {
                //If the state of the game 'GameState' is set to start, it will draw titlescreen
                case GameState.Start:
                    GraphicsDevice.Clear(Color.White);
                    spriteBatch.Begin();
                    spriteBatch.Draw(titlescreen, new Rectangle(0, 0, Window.ClientBounds.Width,
                            Window.ClientBounds.Height), null, Color.White, 0,Vector2.Zero, SpriteEffects.None, 0);
                    spriteBatch.End();
                    break;

                //If the state of the game is set to ingame, it will draw gamescreen
                case GameState.InGame:
                    GraphicsDevice.Clear(Color.White);
                    spriteBatch.Begin();
                    spriteBatch.Draw(gamescreen, new Rectangle(0, 0, Window.ClientBounds.Width,
                            Window.ClientBounds.Height), null, Color.White, 0, Vector2.Zero, SpriteEffects.None, 0);
                    spriteBatch.End();
                    break;

                //If the state of the game is set to gameover, it will draw the endscreen
                case GameState.GameOver:
                    GraphicsDevice.Clear(Color.White);
                    spriteBatch.Begin();
                    spriteBatch.Draw(endscreen, new Rectangle(0, 0, Window.ClientBounds.Width,
                            Window.ClientBounds.Height), null, Color.White, 0, Vector2.Zero, SpriteEffects.None, 0);
                    spriteBatch.End();
                    break;
            }
            #endregion

            base.Draw(gameTime);
        }
    }
}
