﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;


namespace GameState 
{
    public class SpriteManager : Microsoft.Xna.Framework.DrawableGameComponent
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        Texture2D background;
        Rectangle mainFrame;
        SpriteFont TextFont;
        Sprite cursor;
        //List of all the points that the planes will fly too
        public List<Vector2> wayPoints = new List<Vector2>();
        //Queue with planes
        List<Plane> Wave1 = new List<Plane>();
        const int wave1Size = 5;//Number of planes in wave
        //Random speed for the planes
        Random randSpeed = new Random();

        public SpriteManager(Game game)
            : base(game)
        {
            wayPoints.Add(new Vector2(714, 56));
            wayPoints.Add(new Vector2(79, 56));
            wayPoints.Add(new Vector2(79, 440));
            wayPoints.Add(new Vector2(430, 448));
        }
                
        public override void Initialize()
        {
            

            base.Initialize();
        }

        protected override void LoadContent()
        {
            //Background Picture
            mainFrame = new Rectangle(0, 0, GraphicsDevice.Viewport.Width, GraphicsDevice.Viewport.Height);
            
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            //Need to put the wayPoints in the list so the planes can travel.

            background = Game.Content.Load<Texture2D>(@"Images/BackgroundPath");

            cursor = new Sprite(Game.Content.Load<Texture2D>(@"Images/cursor"),
                new Vector2(GraphicsDevice.Viewport.Width / 2, GraphicsDevice.Viewport.Height / 2), 10f);

            for (int i = 0; i < wave1Size; i++)
            {
                Wave1.Add(new Plane(Game.Content.Load<Texture2D>(@"Images/planeNormal"),
                new Vector2(716, 56/*(float)GraphicsDevice.Viewport.Height / 8*/),
                ((randSpeed.Next(3) + 3) * .25f)));
            }

            base.LoadContent();
        }

        public override void Update(GameTime gameTime)
        {
            cursor.Update(gameTime, Game.Window.ClientBounds);


            #region Different Planes for Damage
            //If health for plane is zero it delete from the list or changes the pic of the plane based on damage
            for (int i = 0; i < wave1Size; i++)
            {
                if (Wave1[i].health == 0)
                    Wave1.RemoveAt(i);
                else if (Wave1[i].health <= 10)
                    Wave1[i].textureImage = Game.Content.Load<Texture2D>(@"Images/planeFire2");
                else if (Wave1[i].health <= 20)
                    Wave1[i].textureImage = Game.Content.Load<Texture2D>(@"Images/planeRed");
                else if (Wave1[i].health <= 50)
                    Wave1[i].textureImage = Game.Content.Load<Texture2D>(@"Images/planeYellow");
                else if (Wave1[i].health <= 85)
                    Wave1[i].textureImage = Game.Content.Load<Texture2D>(@"Images/planeOrange");
                else
                    Wave1[i].textureImage = Game.Content.Load<Texture2D>(@"Images/planeNormal");
            }
            #endregion

            //Calls all the planes update function
            foreach (Plane plane in Wave1)
            {
                plane.Update(gameTime, Game.Window.ClientBounds);
            }    

            base.Update(gameTime);
        }

        public override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            spriteBatch.Begin(SpriteBlendMode.AlphaBlend, SpriteSortMode.FrontToBack, SaveStateMode.None);

            //Drawing all the ships to the screen in the list 
            foreach (Plane plane in Wave1)
            {
                plane.Draw(gameTime, spriteBatch);
            }

            //Drawing Background on the screen
            spriteBatch.Draw(background, mainFrame, Color.White);
            cursor.Draw(gameTime, spriteBatch);
            //spriteBatch.DrawString(TextFont, "Direction: (" + (float)Wave1[1].direction.X + " , " + (float)Wave1[1].direction.Y + " )", new Vector2(0, 0), Color.White);
            spriteBatch.End();

            base.Draw(gameTime);
        }    
    }
}
